.. rst-class:: detail

RosClient.remove_attached_collision_mesh
===================================================

.. currentmodule:: compas_rrc

.. automethod:: RosClient.remove_attached_collision_mesh